@@ -1,9 +1,7 @@
 # Copyright (c) ONNX Project Contributors
 
 # SPDX-License-Identifier: Apache-2.0
-
-
-from typing import List, Optional, Tuple
+from __future__ import annotations
 
 import numpy as np
 
@@ -12,8 +10,8 @@ from onnx.reference.op_run import OpRun
 
 class SplitToSequence(OpRun):
     def common_run(
-        self, mat: np.ndarray, split: Optional[np.ndarray], axis: int
-    ) -> List[np.ndarray]:
+        self, mat: np.ndarray, split: np.ndarray | None, axis: int
+    ) -> list[np.ndarray]:
         if split is None:
             split_length = [1 for _ in range(mat.shape[axis])]
         elif len(split.shape) == 0:
@@ -40,10 +38,10 @@ class SplitToSequence(OpRun):
     def _run(
         self,
         mat: np.ndarray,
-        split: Optional[np.ndarray] = None,
+        split: np.ndarray | None = None,
         axis: int = 0,
         keepdims: int = 1,
-    ) -> Tuple[np.ndarray]:
+    ) -> tuple[np.ndarray]:
         res = self.common_run(mat, split, axis=axis)
         if split is None and not keepdims:
             for i in range(len(res)):
